@@ -5,10 +5,10 @@ module Network.Wai.Middleware.Local
     ( local
     ) where
 
-import Network.Wai (Middleware,remoteHost, Response)
-import Network.Socket (SockAddr(..))
+import Network.Socket (SockAddr (..))
+import Network.Wai (Middleware, Response, remoteHost)
 
--- | This middleware rejects non-local connections with a specific response. 
+-- | This middleware rejects non-local connections with a specific response.
 --   It is useful when supporting web-based local applications, which would
 --   typically want to reject external connections.
 
@@ -19,8 +19,7 @@ local resp f r k = case remoteHost r of
 #if !defined(mingw32_HOST_OS) && !defined(_WIN32)
                    SockAddrUnix _   -> f r k
 #endif
-                   _                ->  k $ resp
+                   _                ->  k resp
  where
         home :: Integer
-        home = 127 + (256 * 256 * 256) * 1
-
+        home = 127 + (256 * 256 * 256)
