@@ -4,15 +4,14 @@ module Network.Wai.RequestSpec
     , spec
     ) where
 
-import Test.Hspec
 
-import Data.ByteString (ByteString)
-import Network.HTTP.Types (HeaderName)
-import Network.Wai (Request(..), defaultRequest, RequestBodyLength(..))
-
-import Network.Wai.Request
 import Control.Exception (try)
 import Control.Monad (forever)
+import Data.ByteString (ByteString)
+import Network.HTTP.Types (HeaderName)
+import Network.Wai (Request (..), RequestBodyLength (..), defaultRequest)
+import Network.Wai.Request
+import Test.Hspec
 
 main :: IO ()
 main = hspec spec
